@@ -86,19 +86,7 @@ class LazyTableHandle:
         skip: int = 0
     ) -> List[Dict[str, Any]]:
         handle = await self._ensure_resolved()
-        filter_dict = None
-        if filter:
-            if "filterSet" not in filter:
-                filter_set = []
-                for key, value in filter.items():
-                    filter_set.append({
-                        "fieldName": key,
-                        "operator": "is",
-                        "value": value,
-                    })
-                filter_dict = {"filterSet": filter_set, "conjunction": "and"}
-            else:
-                filter_dict = filter
+        filter_dict = await _normalize_filter(handle, filter)
         return await handle.get_records(filter_dict, limit, skip)
 
     async def update_record(self, record_id: str, fields: Dict[str, Any]) -> Dict[str, Any]:
@@ -159,20 +147,7 @@ class TableHandle:
         limit: int = 100,
         skip: int = 0
     ) -> List[Dict[str, Any]]:
-        filter_dict = None
-        if filter:
-            # Если это «короткий» словарь вида {"client_id": "foo", "status": "active"}
-            if "filterSet" not in filter:
-                filter_set = []
-                for key, value in filter.items():
-                    filter_set.append({
-                        "fieldName": key,
-                        "operator": "is",
-                        "value": value,
-                    })
-                filter_dict = {"filterSet": filter_set, "conjunction": "and"}
-            else:
-                filter_dict = filter
+        filter_dict = await _normalize_filter(self, filter)
         return await self._client.get_records(self.base_id, self.table_id, filter_dict, limit, skip)
 
     async def update_record(self, record_id: str, fields: Dict[str, Any]) -> Dict[str, Any]:
@@ -757,6 +732,33 @@ def table_sync(space_name: str, base_name: str, table_name: str) -> LazyTableHan
         except Exception:
             pass
 
+async def _normalize_filter(table_handle, simple_filter: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:
+    """Преобразует {fieldName: value} в правильный filterSet c fieldId."""
+    if not simple_filter:
+        return None
+
+    # Если это уже filterSet – ничего не делаем
+    if "filterSet" in simple_filter:
+        return simple_filter
+
+    info = await table_handle.get_info()
+    fields = info.get("fields", [])
+    field_map = {f["name"]: f["field_id"] for f in fields if "field_id" in f}
+
+    filter_set = []
+    for key, value in simple_filter.items():
+        field_id = field_map.get(key)
+        if not field_id:
+            table_name = getattr(table_handle, "table_name", None) or getattr(table_handle, "name", None)
+            raise TableError(f"Field '{key}' not found in table {table_name or '?'}")
+        filter_set.append({
+            "fieldId": field_id,
+            "operator": "=",   # по умолчанию равенство
+            "value": value
+        })
+
+    return {"filterSet": filter_set, "conjunction": "and"}
+
 
 class _TableProxy:
     def __call__(self, space_name: str, base_name: str, table_name: str) -> LazyTableHandle:
